import { paths } from './generated/openapi.ts';
import type { ClientOptions, FetchOptions, FetchResponse, MaybeOptionalInit } from "openapi-fetch";
import createClient from "openapi-fetch";
import type { PathsWithMethod } from "openapi-typescript-helpers";
export interface BrowserStackOptions extends ClientOptions {
    username?: string;
    key?: string;
    /**
     * @internal
     */
    usernameOptional?: boolean;
}
/**
 * @internal
 */
export type ExtraRequestOptions = {
    useSdkCloud?: boolean | undefined;
} | undefined;
export type APIFetchOptions<T> = Omit<FetchOptions<T>, "params" | "body">;
/**
 * @internal
 */
export declare class APIClient {
    protected readonly sdk: ReturnType<typeof createClient<paths>>;
    protected readonly sdkCloud: ReturnType<typeof createClient<paths>>;
    constructor(options: BrowserStackOptions);
    /**
     * @internal
     */
    protected makeGetRequest<P extends PathsWithMethod<paths, "get">, I extends MaybeOptionalInit<paths[P], "get">>(path: P, ...init: I): Promise<NonNullable<FetchResponse<paths[P]["get"], I[0]>["data"]>>;
    /**
     * @internal
     */
    protected makePostRequest<P extends PathsWithMethod<paths, "post">, I extends MaybeOptionalInit<paths[P], "post">>(path: P, ...init: I): Promise<NonNullable<FetchResponse<paths[P]["post"], I[0]>["data"]>>;
    /**
     * @internal
     */
    protected makeCloudGetRequest<P extends PathsWithMethod<paths, "get">, I extends MaybeOptionalInit<paths[P], "get">>(path: P, ...init: I): Promise<NonNullable<FetchResponse<paths[P]["get"], I[0]>["data"]>>;
    /**
     * @internal
     */
    protected makeCloudPostRequest<P extends PathsWithMethod<paths, "post">, I extends MaybeOptionalInit<paths[P], "post">>(path: P, ...init: I): Promise<NonNullable<FetchResponse<paths[P]["post"], I[0]>["data"]>>;
    /**
     * @internal
     */
    protected makePutRequest<P extends PathsWithMethod<paths, "put">, I extends MaybeOptionalInit<paths[P], "put">>(path: P, ...init: I): Promise<NonNullable<FetchResponse<paths[P]["put"], I[0]>["data"]>>;
    /**
     * @internal
     */
    protected makePatchRequest<P extends PathsWithMethod<paths, "patch">, I extends MaybeOptionalInit<paths[P], "patch">>(path: P, ...init: I): Promise<NonNullable<FetchResponse<paths[P]["patch"], I[0]>["data"]>>;
    /**
     * @internal
     */
    protected makeDeleteRequest<P extends PathsWithMethod<paths, "delete">, I extends MaybeOptionalInit<paths[P], "delete">>(path: P, ...init: I): Promise<NonNullable<FetchResponse<paths[P]["delete"], I[0]>["data"]>>;
}
